==> phpicalendar-2.1p0.tgz: phpicalendar/languages/german.inc.php <==
<?php

// German language include
// For version 2.0 PHP iCalendar
//
// Translation by David Reindl (dre@andare.ch)
// Corrected by whippersnapper slomo (mail@slomo.de)
// Revised for version 2.0 by Holger Schleicher (holger@vc4.de)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= 'Tag';
$lang['l_week'] 			= 'Woche';
$lang['l_month'] 			= 'Monat';
$lang['l_year'] 			= 'Jahr';
$lang['l_calendar'] 		= 'Kalender';
$lang['l_next_day'] 		= 'Folgender Tag';
$lang['l_next_month'] 		= 'Folgender Monat';
$lang['l_next_week'] 		= 'Folgende Woche';
$lang['l_next_year'] 		= 'Folgendes Jahr';
$lang['l_last_day'] 		= 'Vorheriger Tag';
$lang['l_last_month'] 		= 'Vorheriger Monat';
$lang['l_last_week'] 		= 'Vorherige Woche';
$lang['l_last_year'] 		= 'Vorheriges Jahr';
$lang['l_subscribe'] 		= 'Abbonieren';
$lang['l_download'] 		= 'Herunterladen';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event'] 			= 'Eintrag';
$lang['l_event_start'] 		= 'Beginn';
$lang['l_event_end'] 		= 'Ende';
$lang['l_this_months'] 		= 'Eintr&auml;ge in diesem Monat';
$lang['l_date'] 			= 'Datum';
$lang['l_summary'] 			= 'Beschreibung';
$lang['l_all_day'] 			= 'Tagesereignis';
$lang['l_notes'] 			= 'Notiz';
$lang['l_this_years'] 		= 'Eintr&auml;ge f&uuml;r dieses Jahr';
$lang['l_today'] 			= 'Heute';
$lang['l_this_week'] 		= 'Diese Woche';
$lang['l_this_month'] 		= 'Diesen Monat';
$lang['l_jump'] 			= 'Gehe zu';
$lang['l_tomorrows'] 		= 'Morgige Eintr&auml;ge';
$lang['l_goday'] 			= 'Gehe zum heutigen Tag';
$lang['l_goweek'] 			= 'Gehe zur aktuellen Woche';
$lang['l_gomonth'] 			= 'Gehe zum aktuellen Monat';
$lang['l_goyear'] 			= 'Gehe zum aktuellen Jahr';
$lang['l_search'] 			= 'Suchen'; // the verb
$lang['l_results'] 			= 'Suchergebnisse';
$lang['l_query'] 			= 'Suche'; // will be followed by the search query
$lang['l_no_results'] 		= 'Keine Eintr&auml;ge gefunden';
$lang['l_goprint'] 			= 'Druckversion';
$lang['l_time'] 			= 'Zeit';
$lang['l_summary'] 			= 'Zusammenfassung';
$lang['l_description'] 		= 'Beschreibung';
$lang['l_this_site_is']		= 'Diese Site ist';
$lang['l_no_events_day']	= 'Keine Eintr&auml;ge f&uuml;r heute.';
$lang['l_no_events_week']	= 'Keine Eintr&auml;ge in dieser Woche.';
$lang['l_no_events_month']	= 'Keine Eintr&auml;ge in diesem Monat.';
$lang['l_rss_day_date']		= 'H:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%e. %b';  // Lists just the day
$lang['l_rss_month_date	']	= '%e. %b';  // Lists just the day
$lang['l_rss_language']		= 'de-de';
$lang['l_search_took']		= 'Suche dauerte %s Sekunden';
$lang['l_recurring_event']	= 'Wiederkehrender Eintrag';
$lang['l_exception']		= 'Ausnahme';
$lang['l_no_query']			= 'Kein Suchbegriff';
$lang['l_preferences']		= 'Einstellungen';
$lang['l_printer']			= 'Drucker';
$lang['l_select_lang']		= 'Standardsprache w&auml;hlen:';
$lang['l_select_cal']		= 'Standardkalender w&auml;hlen:';
$lang['l_select_view']		= 'Standardansicht  w&auml;hlen:';
$lang['l_select_time']		= 'Tag beginnt um:';
$lang['l_select_day']		= 'Woche beginnt mit:';
$lang['l_select_style']		= 'Standardstil w&auml;hlen:';
$lang['l_set_prefs']		= 'Einstellungen speichern';
$lang['l_completed_date']	= 'Erledigt am';
$lang['l_completed']		= 'Erledigt';
$lang['l_created']			= 'Erstellt';
$lang['l_due']				= 'F&auml;llig:';
$lang['l_priority']			= 'Priorit&auml;t:';
$lang['l_priority_high']	= 'hoch';
$lang['l_priority_low']		= 'niedrig';
$lang['l_priority_medium']	= 'mittel';
$lang['l_priority_none']	= 'keine';
$lang['l_status']			= 'Status';
$lang['l_todo']				= 'Aufgaben';
$lang['l_unfinished']		= 'Andauernd';
$lang['l_prefs_set'] 		= 'Einstellungen wurden gespeichert.';
$lang['l_prefs_unset'] 		= 'Einstellungen gel&ouml;scht. &Auml;nderungen werden beim Aufruf der n&auml;chsten Seite aktiv.';
$lang['l_unset_prefs'] 		= 'Einstellungen l&ouml;schen:';
$lang['l_organizer']		= 'Organisator';
$lang['l_attendee']			= 'Teilnehmer';
$lang['l_location']			= 'Ort';
$lang['l_admin_header']		= 'PHP iCalendar Administration';
$lang['l_username']			= 'Benutzername';
$lang['l_password']			= 'Passwort';
$lang['l_login']			= 'Anmelden';
$lang['l_invalid_login']	= 'Falscher Benutzername oder Passwort.';
$lang['l_addupdate_cal']	= 'Kalender aktualisieren oder hochladen';
$lang['l_addupdate_desc']	= 'Um einen Kalendar hinzuzuf&uuml;gen, laden Sie ein neues Kalender Dokument hoch. Um einen Kalender zu aktualisieren, laden Sie ein Kalender Dokument mit dem selben Namen hoch.';
$lang['l_delete_cal']		= 'Einen Kalender l&ouml;schen';
$lang['l_logout']			= 'Abmelden';
$lang['l_cal_file']			= 'Kalender Dokument';
$lang['l_php_error']		= 'PHP Fehler';
$upload_error_gen_lang		= 'Es ist ein Problem beim Hochladen aufgetreten.';
$upload_error_lang[0]		= 'Fehler beim Hochladen des Dokuments.';
$upload_error_lang[1]		= 'Das hochzuladende Dokument ist zu gross.';
$upload_error_lang[2]		= 'Das Dokument, welches Sie versuchen hochzuladen, ist zu gross.';
$upload_error_lang[3]		= 'Das Dokument, welches Sie versuchen hochzuladen wurde nur teilweise empfangen.';
$upload_error_lang[4]		= 'Sie m&uuml;ssen ein Dokument zum Hochladen ausw&auml;hlen.';
$lang['l_upload_error_type'] = 'Nur Dokumente mit der Suffix .ics d&uuml;rfen hochgeladen werden.';
$lang['l_copy_error']			= 'Kopieren des Dokuments nicht erfolgreich';
$lang['l_delete_error']			= 'L&ouml;schen des Dokuments nicht erfolgreich';
$lang['l_delete_success']		= 'wurde gel&ouml;scht.';
$lang['l_action_success']		= 'Die Aktion war erfolgreich.';
$lang['l_submit']				= 'Absenden';
$lang['l_delete']				= 'L&ouml;schen';
$all_cal_comb_lang			= 'Alle Kalender zusammen';

// New for 2.0
$lang['l_legend']			= 'Legende';
$lang['l_admin_subhead']	= 'Verwalten Sie Ihre Kalender mit dieser Seite';
$lang['l_prefs_subhead']	= 'Sets a cookie for visiting this site';
$lang['l_rss_info']			= 'RSS Information';
$lang['l_rss_subhead']		= 'Basic RSS feeds available for each calendar';
$lang['l_rss_notenabled']	= 'RSS is not enabled on this site';

// - navigation
$lang['l_back'] 		= 'Zur&uuml;ck';
$lang['l_next'] 		= 'N&auml;chste';
$lang['l_prev'] 		= 'Vorherige';
$lang['l_day_view'] 	= 'Tagesansicht';
$lang['l_week_view'] 	= 'Wochenansicht';
$lang['l_month_view'] 	= 'Monatsansicht';
$lang['l_year_view'] 	= 'Jahresansicht';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('Jahr','Jahre');		// for these, put singular
$format_recur_lang['monthly']		= array('Monat','Monate');		// and plural forms
$format_recur_lang['weekly']		= array('Woche','Wochen');		// these will be %freq%
$format_recur_lang['daily']			= array('Tag','Tage');			// in the replacement below
$format_recur_lang['hourly']		= array('Stunde','Stunden');
$format_recur_lang['minutely']		= array('Minute','Minuten');
$format_recur_lang['secondly']		= array('Sekunde','Sekunden');

$format_recur_lang['start']			= 'Jeden %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'bis %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'f&uuml;r %int% Mal';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'In den Monaten: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'An den Daten: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'An den Tagen: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Sonntag','Montag','Dienstag','Mittwoch','Donerstag','Freitag','Samstag');
$daysofweekshort_lang		= array ('Son','Mon','Die','Mit','Don','Fre','Sam');
$daysofweekreallyshort_lang	= array ('S','M','D','M','D','F','S');
$monthsofyear_lang			= array ('Januar','Februar','M&auml;rz','April','Mai','Juni','Juli','August','September','Oktober','November','Dezember');
$monthsofyearshort_lang		= array ('Jan','Feb','M&auml;r','Apr','Mai','Jun','Jul','Aug','Sep','Okt','Nov','Dez');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'H:i';
$timeFormat_small = 'H:i';

// For date formatting, see note below
$dateFormat_day = '%A, %e. %B';
$dateFormat_week = '%B %e';
$dateFormat_week_list = '%a, %e. %b';
$dateFormat_week_jump = ' %e. %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %e. %B';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Fehler!';
$lang['l_error_window'] 		= 'Es ist ein Fehler aufgetreten!';
$lang['l_error_calendar'] 		= 'Der Kalender "%s" wurde bearbeitet, als dieser Fehler auftrat.';
$lang['l_error_path'] 			= 'Der Pfad "%s" kann nicht ge&ouml;ffnet werden.';
$lang['l_error_back'] 			= 'Bitte klicken Sie die "Zur&uuml;ck" Schaltfl&auml;che des Browsers um zur&uuml;ckzuspringen.';
$lang['l_error_remotecal'] 		= 'Dieser Server blockiert entfernte Kalender, welche nicht freigegeben wurden.';
$lang['l_error_restrictedcal'] 	= 'Sie haben versucht einen Kalender mit eingeschr&auml;nktem Zugriff auf diesem Server aufzurufen.';
$lang['l_error_invalidcal'] 	= 'Dieser Kalender enth&auml;lt Fehler. Bitte w&auml;hlen Sie einen anderen aus.';

?>

==> phpicalendar-2.31.tgz: phpicalendar/languages/german.inc.php <==
﻿<?php

// German language include
// For version 2.0 PHP iCalendar
//
// Translation by David Reindl (dre@andare.ch)
// Corrected by whippersnapper slomo (mail@slomo.de)
// Revised for version 2.0 by Holger Schleicher (holger@vc4.de)
//
// Submit new translations to phpicalendar@gmail.com

$lang['l_day'] 				= 'Tag';
$lang['l_week'] 			= 'Woche';
$lang['l_month'] 			= 'Monat';
$lang['l_year'] 			= 'Jahr';
$lang['l_calendar'] 		= 'Kalender';
$lang['l_next_day'] 		= 'Folgender Tag';
$lang['l_next_month'] 		= 'Folgender Monat';
$lang['l_next_week'] 		= 'Folgende Woche';
$lang['l_next_year'] 		= 'Folgendes Jahr';
$lang['l_last_day'] 		= 'Vorheriger Tag';
$lang['l_last_month'] 		= 'Vorheriger Monat';
$lang['l_last_week'] 		= 'Vorherige Woche';
$lang['l_last_year'] 		= 'Vorheriges Jahr';
$lang['l_subscribe'] 		= 'Abbonieren';
$lang['l_download'] 		= 'Herunterladen';
$lang['l_powered_by'] 		= 'Powered by';
$lang['l_event'] 			= 'Eintrag';
$lang['l_event_start'] 		= 'Beginn';
$lang['l_event_end'] 		= 'Ende';
$lang['l_this_months'] 		= 'Einträge in diesem Monat';
$lang['l_date'] 			= 'Datum';
$lang['l_summary'] 			= 'Beschreibung';
$lang['l_all_day'] 			= 'Tagesereignis';
$lang['l_notes'] 			= 'Notiz';
$lang['l_this_years'] 		= 'Einträge für dieses Jahr';
$lang['l_today'] 			= 'Heute';
$lang['l_this_week'] 		= 'Diese Woche';
$lang['l_this_month'] 		= 'Diesen Monat';
$lang['l_jump'] 			= 'Gehe zu';
$lang['l_tomorrows'] 		= 'Morgige Einträge';
$lang['l_goday'] 			= 'Gehe zum heutigen Tag';
$lang['l_goweek'] 			= 'Gehe zur aktuellen Woche';
$lang['l_gomonth'] 			= 'Gehe zum aktuellen Monat';
$lang['l_goyear'] 			= 'Gehe zum aktuellen Jahr';
$lang['l_search'] 			= 'Suchen'; // the verb
$lang['l_results'] 			= 'Suchergebnisse';
$lang['l_pick_multiple'] 	= 'Mehrfachauswahl';
$lang['l_query'] 			= 'Suche'; // will be followed by the search query
$lang['l_no_results'] 		= 'Keine Einträge gefunden';
$lang['l_goprint'] 			= 'Druckversion';
$lang['l_time'] 			= 'Zeit';
$lang['l_summary'] 			= 'Zusammenfassung';
$lang['l_description'] 		= 'Beschreibung';
$lang['l_this_site_is']		= 'Diese Site ist';
$lang['l_no_events_day']	= 'Keine Einträge für heute.';
$lang['l_no_events_week']	= 'Keine Einträge in dieser Woche.';
$lang['l_no_events_month']	= 'Keine Einträge in diesem Monat.';
$lang['l_rss_day_date']		= 'H:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%e. %b';  // Lists just the day
$lang['l_rss_month_date	']	= '%e. %b';  // Lists just the day
$lang['l_rss_language']		= 'de-de';
$lang['l_search_took']		= 'Suche dauerte %s Sekunden';
$lang['l_recurring_event']	= 'Wiederkehrender Eintrag';
$lang['l_exception']		= 'Ausnahme';
$lang['l_no_query']			= 'Kein Suchbegriff';
$lang['l_preferences']		= 'Einstellungen';
$lang['l_printer']			= 'Drucker';
$lang['l_select_lang']		= 'Standardsprache wählen';
$lang['l_select_cal']		= 'Standardkalender wählen';
$lang['l_select_view']		= 'Standardansicht  wählen';
$lang['l_select_time']		= 'Tag beginnt um';
$lang['l_select_day']		= 'Woche beginnt mit';
$lang['l_select_style']		= 'Standardstil wählen';
$lang['l_set_prefs']		= 'Einstellungen speichern';
$lang['l_completed_date']	= 'Erledigt am';
$lang['l_completed']		= 'Erledigt';
$lang['l_created']			= 'Erstellt';
$lang['l_due']				= 'Fällig:';
$lang['l_priority']			= 'Priorität:';
$lang['l_priority_high']	= 'hoch';
$lang['l_priority_low']		= 'niedrig';
$lang['l_priority_medium']	= 'mittel';
$lang['l_priority_none']	= 'keine';
$lang['l_status']			= 'Status';
$lang['l_status_confirmed'] = 'Bestätigt' ; 
$lang['l_status_cancelled'] = 'Abgesagt'; 
$lang['l_status_tentative'] = 'Vorläufig'; 
$lang['l_todo']				= 'Aufgaben';
$lang['l_unfinished']		= 'Andauernd';
$lang['l_prefs_set'] 		= 'Einstellungen wurden gespeichert.';
$lang['l_prefs_unset'] 		= 'Einstellungen gelöscht. änderungen werden beim Aufruf der nächsten Seite aktiv.';
$lang['l_unset_prefs'] 		= 'Einstellungen löschen';
$lang['l_organizer']		= 'Organisator';
$lang['l_attendee']			= 'Teilnehmer';
$lang['l_location']			= 'Ort';
$lang['l_admin_header']		= 'PHP iCalendar Administration';
$lang['l_username']			= 'Benutzername';
$lang['l_password']			= 'Passwort';
$lang['l_login']			= 'Anmelden';
$lang['l_invalid_login']	= 'Falscher Benutzername oder Passwort.';
$lang['l_addupdate_cal']	= 'Kalender aktualisieren oder hochladen';
$lang['l_addupdate_desc']	= 'Um einen Kalendar hinzuzufügen, laden Sie ein neues Kalender Dokument hoch. Um einen Kalender zu aktualisieren, laden Sie ein Kalender Dokument mit dem selben Namen hoch.';
$lang['l_delete_cal']		= 'Einen Kalender löschen';
$lang['l_logout']			= 'Abmelden';
$lang['l_cal_file']			= 'Kalender Dokument';
$lang['l_php_error']		= 'PHP Fehler';
$upload_error_gen_lang		= 'Es ist ein Problem beim Hochladen aufgetreten.';
$upload_error_lang[0]		= 'Fehler beim Hochladen des Dokuments.';
$upload_error_lang[1]		= 'Das hochzuladende Dokument ist zu gross.';
$upload_error_lang[2]		= 'Das Dokument, welches Sie versuchen hochzuladen, ist zu gross.';
$upload_error_lang[3]		= 'Das Dokument, welches Sie versuchen hochzuladen wurde nur teilweise empfangen.';
$upload_error_lang[4]		= 'Sie müssen ein Dokument zum Hochladen auswählen.';
$lang['l_upload_error_type'] = 'Nur Dokumente mit der Suffix .ics dürfen hochgeladen werden.';
$lang['l_copy_error']			= 'Kopieren des Dokuments nicht erfolgreich';
$lang['l_delete_error']			= 'Löschen des Dokuments nicht erfolgreich';
$lang['l_delete_success']		= 'wurde gelöscht.';
$lang['l_action_success']		= 'Die Aktion war erfolgreich.';
$lang['l_submit']				= 'Absenden';
$lang['l_delete']				= 'Löschen';
$all_cal_comb_lang			= 'Alle Kalender zusammen';

// New for 2.0
$lang['l_legend']			= 'Legende';
$lang['l_admin_subhead']	= 'Verwalten Sie Ihre Kalender mit dieser Seite';
$lang['l_prefs_subhead']	= 'Sets a cookie for visiting this site';
$lang['l_rss_info']			= 'RSS Information';
$lang['l_rss_subhead']		= 'Basic RSS feeds available for each calendar';
$lang['l_rss_notenabled']	= 'RSS is not enabled on this site';

// - navigation
$lang['l_back'] 		= 'Zurück';
$lang['l_next'] 		= 'Nächste';
$lang['l_prev'] 		= 'Vorherige';
$lang['l_day_view'] 	= 'Tagesansicht';
$lang['l_week_view'] 	= 'Wochenansicht';
$lang['l_month_view'] 	= 'Monatsansicht';
$lang['l_year_view'] 	= 'Jahresansicht';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('Jahr','Jahre');		// for these, put singular
$format_recur_lang['monthly']		= array('Monat','Monate');		// and plural forms
$format_recur_lang['weekly']		= array('Woche','Wochen');		// these will be %freq%
$format_recur_lang['daily']			= array('Tag','Tage');			// in the replacement below
$format_recur_lang['hourly']		= array('Stunde','Stunden');
$format_recur_lang['minutely']		= array('Minute','Minuten');
$format_recur_lang['secondly']		= array('Sekunde','Sekunden');

$format_recur_lang['start']			= 'Jeden %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'bis %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'für %int% Mal';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'In den Monaten: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'An den Daten: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'An den Tagen: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Sonntag','Montag','Dienstag','Mittwoch','Donnerstag','Freitag','Samstag');
$daysofweekshort_lang		= array ('So','Mo','Di','Mi','Do','Fr','Sa');
$daysofweekreallyshort_lang	= array ('So','Mo','Di','Mi','Do','Fr','Sa');
$monthsofyear_lang			= array ('Januar','Februar','März','April','Mai','Juni','Juli','August','September','Oktober','November','Dezember');
$monthsofyearshort_lang		= array ('Jan','Feb','Mär','Apr','Mai','Jun','Jul','Aug','Sep','Okt','Nov','Dez');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'H:i';
$timeFormat_small = 'H:i';

// For date formatting, see note below
$dateFormat_day = '%A, %e. %B';
$dateFormat_week = '%B %e';
$dateFormat_week_list = '%a, %e. %b';
$dateFormat_week_jump = ' %e. %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %e. %B';
$dateFormat_year = '%Y';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Fehler!';
$lang['l_error_window'] 		= 'Es ist ein Fehler aufgetreten!';
$lang['l_error_calendar'] 		= 'Der Kalender "%s" wurde bearbeitet, als dieser Fehler auftrat.';
$lang['l_error_path'] 			= 'Der Pfad "%s" kann nicht geöffnet werden.';
$lang['l_error_back'] 			= 'Bitte klicken Sie die "Zurück" Schaltfläche des Browsers um zurückzuspringen.';
$lang['l_error_remotecal'] 		= 'Dieser Server blockiert entfernte Kalender, welche nicht freigegeben wurden.';
$lang['l_error_restrictedcal'] 	= 'Sie haben versucht einen Kalender mit eingeschränktem Zugriff auf diesem Server aufzurufen.';
$lang['l_error_invalidcal'] 	= 'Dieser Kalender enthält Fehler. Bitte wählen Sie einen anderen aus.';

?>
